@@ -153,10 +153,10 @@ def deploy_scikit(scikit_model, name):
 
   version = new_version(model['id'])
 
-  if os.path.exists('./inferrd-scikit'):
-    shutil.rmtree('./inferrd-scikit')
+  if os.path.exists('./inferrd-scikit.joblib'):
+    os.remove('./inferrd-scikit.joblib')
 
-  dump(scikit_model, './inferrd-scikit')
+  dump(scikit_model, './inferrd-scikit.joblib')
 
   print('> Zipping model for upload')
 
@@ -164,7 +164,7 @@ def deploy_scikit(scikit_model, name):
     os.remove('./model.zip')
 
   zipf = zipfile.ZipFile('model.zip', 'w', zipfile.ZIP_DEFLATED)
-  zipf.write('./inferrd-scikit', 'model.joblib')
+  zipf.write('./inferrd-scikit.joblib', './model.joblib')
   zipf.close()
 
   # upload to storage
@@ -175,7 +175,7 @@ def deploy_scikit(scikit_model, name):
   print('> Deploying version v' + str(version['number']))
   deploy_version(version['id'])
 
-  shutil.rmtree('./inferrd-scikit')
+  os.remove('./inferrd-scikit.joblib')
   os.remove('./model.zip')
 
   print('> Scikit Model deployed')
@@ -231,4 +231,14 @@ def get_request_history(apiKey, kwargs):
 
 def call_model(serveKey, payload):
   r = requests.post(api_host + '/infer/' + serveKey, data=json.dumps(payload), headers={'Content-Type': 'application/json'})
-  return r.json()
\ No newline at end of file
+  return r.json()
+
+def get(modelName):
+  model = get_model(modelName)
+  serveKey = model.serveKey
+
+  def infer(payload):
+    r = requests.post(api_host + '/infer/' + serveKey, data=json.dumps(payload), headers={'Content-Type': 'application/json'})
+  return r.json()
+
+  return infer
\ No newline at end of file
